.. _spkg_zlib:

zlib: Data compression library
==============================

Description
-----------

Massively Spiffy Yet Delicately Unobtrusive Compression Library (Also
Free, Not to Mention Unencumbered by Patents)

License
-------

-  Modified BSD.


Upstream Contact
----------------

-  http://www.zlib.net/


Type
----

standard


Dependencies
------------



Version Information
-------------------

package-version.txt::

    1.3.1

See https://repology.org/project/zlib/versions

Installation commands
---------------------

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i zlib

.. tab:: Alpine:

   .. CODE-BLOCK:: bash

       $ apk add zlib-dev

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install zlib

.. tab:: Debian/Ubuntu:

   .. CODE-BLOCK:: bash

       $ sudo apt-get install libz-dev

.. tab:: Fedora/Redhat/CentOS:

   .. CODE-BLOCK:: bash

       $ sudo dnf install zlib-devel

.. tab:: Homebrew:

   .. CODE-BLOCK:: bash

       $ brew install zlib

.. tab:: MacPorts:

   .. CODE-BLOCK:: bash

       $ sudo port install zlib

.. tab:: mingw-w64:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S ${MINGW_PACKAGE_PREFIX}-zlib

.. tab:: openSUSE:

   .. CODE-BLOCK:: bash

       $ sudo zypper install pkgconfig\(zlib\)

.. tab:: pyodide:

   install the following packages: zlib

.. tab:: Slackware:

   .. CODE-BLOCK:: bash

       $ sudo slackpkg install zlib

.. tab:: Void Linux:

   .. CODE-BLOCK:: bash

       $ sudo xbps-install zlib-devel


If the system package is installed, ``./configure`` will check if it can be used.
